RectElement

Struct RectElement 

pub struct RectElement {
    pub style: StyleState,
    pub layout: LayoutData,
    pub text_style_data: TextStyleData,
    pub relative_layer: Layer,
    pub event_handlers: FxHashMap<EventName, EventHandlerType>,
    pub accessibility: AccessibilityData,
    pub effect: Option<EffectData>,
}

Fields

style: StyleStatelayout: LayoutDatatext_style_data: TextStyleDatarelative_layer: Layerevent_handlers: FxHashMap<EventName, EventHandlerType>accessibility: AccessibilityDataeffect: Option<EffectData>

Implementations

Source

impl RectElement

pub fn render_shadow( canvas: &Canvas, path: &mut SkPath, rounded_rect: SkRRect, _area: Area, shadow: &Shadow, corner_radius: &CornerRadius, )

pub fn render_border( canvas: &Canvas, rect: SkRect, border: &Border, corner_radius: &CornerRadius, )

pub fn border_shape( base_rect: SkRect, base_corner_radius: &CornerRadius, border: &Border, ) -> BorderShape

Returns a Path that will draw a Border around a base rectangle.

We don’t use Skia’s stroking API here, since we might need different widths for each side.